@@ -8,17 +8,12 @@
     return core.opSync("op_format_diagnostic", diagnostics);
   }
 
-  function opFormatFileName(location) {
-    return core.opSync("op_format_file_name", location);
-  }
-
   function opApplySourceMap(location) {
     return core.applySourceMap(location);
   }
 
   window.__bootstrap.errorStack = {
     opFormatDiagnostics,
-    opFormatFileName,
     opApplySourceMap,
   };
 })(this);
